#include <SPI.h>
#include "epd1in54.h"
#include "epdif.h"
#include "epdpaint.h"
#include <RTC.h>
#include <DeviceControlXMC.h>
#include "epdpaint.h"



int COLORED  = 0; // White in Black
int UNCOLORED = 1;  // Black in White
int pos = 20;

XMCClass xmc2go;
RTCClass rtc;

uint32_t sleep = 1; 
uint32_t temperature = 0;
int pwm = 200;
size_t  free_memory;  
unsigned char image[8196];   // takes 8k RAM 
//////////////////////////////////////////////////
// width must be multiple of 8
Paint paint(image, 0, 0);     
Epd epd;                     
//////////////////////////////////////////////////////

void setup() 
{
    flush_epd();  
///// Init Full Display Update ///////////
  if (epd.Init(lut_full_update) != 0) 
  {return;}  
///// Init Partial Display Update ////////
  if (epd.Init(lut_partial_update) != 0) 
  {return;}
////////// Clears Up Full Disp ///////////
// bit set = white, bit reset = black
  epd.ClearFrameMemory(0xFF);   
  epd.DisplayFrame();
  epd.ClearFrameMemory(0xFF);   
  epd.DisplayFrame();

  rtc.begin();
  xmc2go.configureSleepMode(DEEP_SLEEP_MODE,USIC_OFF ,LEDT_OFF,CCU_OFF,WDT_OFF,FLASH_OFF); 
  // active 7.62mA sleep 1.80mA
  // FLASH_ON takes extra 0.55mA
 

  rtc.setTime(0, 0, 0); // hrs, min, sec
  rtc.setDate(0, 0, 0); // day, mon, yrs
  
  rtc.setAlarmTime(0, 0, 1); // 1 sec alarm wakes from sleep
  rtc.enableAlarm(rtc.ALARM);
  rtc.attachInterrupt(alarmMatch);

  // xtra pin io
  pinsInit();

}



void loop() 
{
  int adc0 = analogRead(A0);
  int adc1 = analogRead(A1);
  char VAL[4];
  free_memory = xmc2go.freeRAM_Heap();
  temperature = xmc2go.getTemperature();

  // Set Active Area on Disp with Orientation and Color //
  // more RAM allows more disp area to be used at once
   paint.SetWidth(200);
  paint.SetHeight(200);
  paint.SetRotate(ROTATE_180);
  paint.Clear(UNCOLORED);

    
   if(pwm<=250)
     { pwm=pwm+5; }
   else
     { pwm=0; }
       
   analogWrite(8,pwm);
   
  paint.DrawStringAt(10,20, "ADC0", &Font24, COLORED);
  paint.DrawStringAt(10,50, "ADC1", &Font24, COLORED);
  paint.DrawStringAt(10,80, "PWM0", &Font24, COLORED);
  paint.DrawStringAt(10,110, "SCNT", &Font24, COLORED);
  paint.DrawStringAt(10,140, "FRAM", &Font24, COLORED);
  paint.DrawStringAt(10,170, "DTMP", &Font24, COLORED);

  paint.DrawStringAt(100,20, itoa(adc0,VAL,10), &Font24, COLORED);
  paint.DrawStringAt(100,50, itoa(adc1,VAL,10), &Font24, COLORED);
  paint.DrawStringAt(100,80, itoa(pwm,VAL,10), &Font24, COLORED);
  paint.DrawStringAt(100,110, itoa(sleep,VAL,10), &Font24, COLORED);
  paint.DrawStringAt(100,140, itoa(free_memory,VAL,10), &Font24, COLORED);
  paint.DrawStringAt(100,170, itoa(temperature,VAL,10), &Font24, COLORED);
      
////////////////////////////////////////////////////////////////////////////////
   epd.SetFrameMemory(paint.GetImage(), 0, 0, paint.GetWidth(), paint.GetHeight());
   epd.DisplayFrame();
////////////////////////////////////////////////////////////////////////////////

  xmc2go.enterSleepMode(); // goes to sleep mode
  sleep++;
pinsTest();
} // loop ends here //


// clean up dark spots on epaper display
void flush_epd (void)
{
  if (epd.Init(lut_full_update) != 0) 
  {return;}
  epd.ClearFrameMemory(0xFF);   
  epd.DisplayFrame();
  epd.ClearFrameMemory(0xFF);   
  epd.DisplayFrame();
  
}

// alarm ISR

void alarmMatch()
{
    xmc2go.enterActiveMode();
    rtc.setTime(0, 0, 0); // hrs, min, sec

}

void pinsInit()
{
pinMode(6,OUTPUT);// tx
pinMode(7,OUTPUT);// rx
pinMode(10,OUTPUT);// scl
pinMode(11,OUTPUT);// sda
pinMode(8,OUTPUT);// sda
digitalWrite(6,LOW);
digitalWrite(7,LOW);
digitalWrite(10,LOW);
digitalWrite(11,LOW);
digitalWrite(8,LOW);


  
}

void pinsTest()
{
digitalWrite(6,HIGH);
delay(200);
digitalWrite(6,LOW);
delay(200);

digitalWrite(7,HIGH);
delay(200);
digitalWrite(7,LOW);
delay(200);

digitalWrite(8,HIGH);
delay(200);
digitalWrite(8,LOW);
delay(200);

digitalWrite(10,HIGH);
delay(200);
digitalWrite(10,LOW);
delay(200);

digitalWrite(11,HIGH);
delay(200);
digitalWrite(11,LOW);
delay(200);




}
